tonalitytools.InversionIndicator
================================

.. abjad-lineage:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator

.. autoclass:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.name
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.number
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.storage_format
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.title
   :noindex:

Methods
-------

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.extent_to_figured_bass_string
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__ge__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__gt__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__le__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__lt__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__repr__
   :noindex:
